@@ -17,17 +17,31 @@ function squirrelmail_plugin_init_serversidefilter() {
 function serversidefilter_optpage_register_block() {
 	global $optpage_blocks;
 
+        if (defined("SM_PATH")) {
+	    bindtextdomain ('serversidefilter', SM_PATH . 'locale');
+	} else {
+	    bindtextdomain ('serversidefilter', '../locale');
+	}
+	textdomain ('serversidefilter');
+
         $optpage_blocks[] = 
 		array(
 			'name' => _("Mail Filters"),
 			'url'  => '../plugins/serversidefilter/options.php',
 			'desc' => _("Here you may set up server-side filters on all of your incoming mail."),
 			'js'   => FALSE);
+
+	if (defined("SM_PATH")) {
+	    bindtextdomain('squirrelmail', SM_PATH . 'locale');
+	} else {
+	    bindtextdomain ('squirrelmail', '../locale');
+	}
+	textdomain('squirrelmail');
 }
 
 function serversidefilter_version() {
 
-         return '1.32';
+         return '1.42';
 
 }
 
